..  Titling
    ##++::==~~--''``

.. This is a reStructuredText file.

Change Log
::::::::::

0.2.0
=====

* Bring in modules and tests from `Tea and Sympathy`.

0.1.0
=====

* Package structure established.
